function int_demo
% INT_DEMO
% Illustrates multi-level method for integral equations.
%
% Solves simple integral equation from the lectures.
% Exact coarse mesh solve.
%
nf = 2049;
nc=33;
hf = 1/(nf-1); xf = 0:hf:1; xf=xf';
[kc, rhsc] = build_data(nc);
[kf, rhsf] = build_data(nf);
mc = eye(nc) - kc;
%
% Coarse grid solve to start the iteration.
%
uf=zeros(nf,1);
tol=1.d-8;
itmax = 100;
itc=0;
rf = uf - kf*uf -rhsf;
while itc < 100 && norm(rf) > 1.d-9
      rc = ftoc(rf,nc);
      vc = mc\rc;
      vf = rf + ctof(kc*vc,nf);
      uf = uf - vf;
      rf = uf - kf*uf -rhsf;
      norm(rf,inf)
end
rf = uf - kf*uf -rhsf;
norm(rf,inf)
plot(xf,uf)


function [kf, rhsf] = build_data(nf);
hf = 1/(nf-1);
xf = 0:hf:1; xf=xf'; rhsf=cos(xf);
wf=hf*ones(nf,1); wf(1)=hf/2; wf(nf)=hf/2;
kf=zeros(nf,nf);
for j=1:nf
   for i=1:nf
      kf(i,j) = .5*sin(xf(i)-xf(j))*wf(j);
   end
end
